 Type GraphicPile 'Stores images and associates them with names 
	Field count:Int 
 	Field names:String[] 
	Field images:TImage[] 
	Function Create:GraphicPile() 'Returns a new graphics pile 
		temp:GraphicPile = New GraphicPile 
		temp.count = 0 
		Return temp 
	End Function 
	Method named:TImage(target:String) 'Returns the image matching the name "target" 
		For t = 0 To count-1 
			If target = names[t] Then 
				Return images[t] 
			End If 
		Next 
		RuntimeError "Asked for a graphic (by name) from a GraphicPile that doesnt exist!" 
	End Method 
	Method numbered:TImage(target:Int) 'Returns the image indexed at "target" 
		If target > count Or target < 0 Then 
			RuntimeError "Asked for a graphic (by index) from a GraphicPile that doesnt exist!" 
		End If 
		Return images[target] 
	End Method 
	Method getIndex:Int(target:String) 'Returns the index for a graphic specified by "target" 
		For t = 0 To count-1 
			If target = names[t] Then 
				 Return t 
			End If 
		Next 
		Return -1
		RuntimeError "Asked for a graphic's index (by name) from a GraphicPile, and it doesnt exist!" 
 	End Method 
	Method add(targetname:String, targetpath:String) 'Adds a new image and a new name into the arrays 
		count = count + 1
		names = names[..count]
		names[count-1] = targetname
		images = images[..count]
		images[count-1] = LoadImage(targetpath)
		If images[count-1] = Null Then
			RuntimeError "Couldnt load image! might not exist!"
		Else
			MidHandleImage(images[count-1])
		End If
	End Method

	Method addandscale(targetname:String, targetpath:String, xsize, ysize) 'See below for comment
		'Adds a new image scaled to the specified sizes in pixels.
		count = count + 1 
		names = names[..count] 
		names[count-1] = targetname 
		images = images[..count] 
		images[count-1] = LoadImage(ResizePixmap(LoadPixmap(targetpath), xsize, ysize))
		If images[count-1] = Null Then 
			RuntimeError "Couldnt load image! might not exist!" 
		End If 
	End Method

	Method PrintContents() 'Prints the names of the images in the GraphicsPile 
		For t = 0 To count-1 
			Print names[t] 
		Next 
	End Method 
 End Type 

 Function LoadImagesFromDir(directory:String, thepile:GraphicPile)
	'Loads all the jpegs and gifs and pngs in the specified "directory" into the GraphicPile "thepile"
	'Do not put a "/" at the end of the directory specification
	directory = directory + "/"
	Local fileNames:String[]
	fileNames=LoadDir(directory) 
	For t:String=EachIn fileNames 
		If Mid(t, t.length - 3, 4) = ".jpg" Or Mid(t, t.length - 3, 4) = ".gif" Or Mid(t, t.length - 3, 4) = ".png" Then
			thepile.add(StripAll(t), directory + t) 
		End If
	Next 
 End Function

 Function LoadScaledImagesFromDir(directory:String, thepile:GraphicPile, x, y)
	'Loads all the jpegs and gifs and pngs in the specified "directory" into the GraphicPile "thepile"
	'As it loads the images, it scales them to the dimensions indicated by x and y
	'Do not put a "/" at the end of the directory specification
	directory = directory + "/"
	Local fileNames:String[]
	fileNames=LoadDir(directory) 
	For t:String=EachIn fileNames 
		If Mid(t, t.length - 3, 4) = ".jpg" Or Mid(t, t.length - 3, 4) = ".gif" Or Mid(t, t.length - 3, 4) = ".png" Then
			thepile.addandscale(StripAll(t), directory + t, x, y) 
		End If
	Next 
 End Function

Function DrawColorPicker(xpos, ypos, xsize, ysize, rval#=0, gval#=0, bval#=0) 'Draws a color picker with r,g,b selected
	lthick# = xsize/3.0
	SetLineWidth(lthick)
	SetColor(255,0,0)
	DrawRect(xpos, ypos, lthick, ysize)
	SetColor(0,255,0)
	DrawRect(xpos + lthick, ypos, lthick, ysize)
	SetColor(0,0,255)
	DrawRect(xpos + 2*lthick, ypos, lthick, ysize)

	rheight = ypos + (((255-rval)/255.0)*ysize)
	gheight = ypos + (((255-gval)/255.0)*ysize)
	bheight = ypos + (((255-bval)/255.0)*ysize)
	SetColor(0,0,0)
	SetLineWidth(2)
	DrawLine(xpos, rheight, xpos + lthick, rheight)
	DrawLine(xpos + lthick, gheight, xpos + lthick*2-1, gheight)
	DrawLine(xpos + lthick*2, bheight, xpos+ lthick*3 -1, bheight)
End Function

Function ColorPickerSelectRed:Int(xpos, ypos, xsize, ysize, rval) 'Uses same inputs as Color Picker, returns red value
	lthick# = xsize/3.0
	mx = MouseX(); my = MouseY()
	
	If mx > xpos And mx <= xpos + lthick Then
		If my >= ypos And my <= ypos + ysize Then
			Return (255-((my - ypos)/(ysize*1.0))*255)
		End If
	End If
	Return rval
End Function

Function ColorPickerSelectGreen:Int(xpos, ypos, xsize, ysize, gval) 'Uses same inputs as Color Picker, returns green value
	lthick# = xsize/3.0
	mx = MouseX(); my = MouseY()
	
	If mx > xpos + lthick And mx <= xpos + lthick*2 Then
		If my >= ypos And my <= ypos + ysize Then
			Return (255-((my - ypos)/(ysize*1.0))*255)
		End If
	End If
	Return gval
End Function

Function ColorPickerSelectBlue:Int(xpos, ypos, xsize, ysize, bval) 'Uses same inputs as Color Picker, returns red value
	lthick# = xsize/3.0
	mx = MouseX(); my = MouseY()
	
	If mx > xpos + lthick*2 And mx <= xpos + lthick*3 Then
		If my >= ypos And my <= ypos + ysize Then
			Return (255-((my - ypos)/(ysize*1.0))*255)
		End If
	End If
	Return bval
End Function












































