Type AudioContext
	Field channelCount
	Field channels:TChannel[]
	Field sounds:TSound[]
	Field playing[]
	Field loopChannels[]
	
	Function create:AudioContext(numChannels)
		ac:audioContext = New audiocontext
		ac.channelcount = numchannels
		ac.channels = New TChannel[numChannels]
		ac.sounds = New TSound[numChannels]
		ac.loopChannels = New Int[numChannels]
		ac.playing = New Int[numchannels]
		For i = 0 To numChannels-1
			ac.channels[i] = AllocChannel()
		Next
		Return ac
	End Function
	
	Method PlaySnd:Int(s:TSound, loop=-1, chan=-1)
		If chan = -1 Then
			For i = 0 To channelCount - 1
				If Not ChannelPlaying(channels[i]) Or playing[i] = 0 Then
					sounds[i] = s
					playing[i] = 1
					PlaySound(s, channels[i])
					If loop <> -1 Then loopChannels[i] = loop
					Return i
				End If
			Next
		Else
			If chan < channelCount Then
				sounds[chan] = s
				playing[chan] = 1
				PlaySound(s, channels[chan])
				If loop <> -1 Then loopChannels[chan] = loop
				Return chan
			End If
		End If
		Return -1
	End Method
	
	Method stopSnd(chan)
		If chan < channelCount And chan >= 0 Then
			playing[chan] = 0
		End If
	End Method
	
	Method update()
		For i = 0 To channelcount - 1
			If Not ChannelPlaying(channels[i]) And loopChannels[i] = 1 Then
				PlaySound(sounds[i], channels[i])
			End If
			If ChannelPlaying(channels[i]) And playing[i] = 0 Then
				PauseChannel(channels[i])
			End If
		Next
	End Method
	
	
	Method inactiveVolumesToZero()
		For i = 0 To channelcount - 1
			If Not ChannelPlaying(channels[i]) Or playing[i] = 0 Then
				SetChannelVolume(channels[i], 0)
			End If
		Next
	End Method
End Type

Type SoundPile 'Stores sounds and associates them with names 
	Field count:Int 
 	Field names:String[] 
	Field sounds:TSound[] 
	Function Create:SoundPile() 'Returns a new soundPile 
		temp:SoundPile = New SoundPile 
		temp.count = 0 
		Return temp 
	End Function 
	Method named:TSound(target:String) 'Returns the sound matching the name "target" 
		For t = 0 To count-1 
			If target = names[t] Then 
				Return sounds[t] 
			End If 
		Next 
		RuntimeError "Asked for a sound (by name) from a SoundPile that doesnt exist!" 
	End Method 
	Method numbered:TSound(target:Int) 'Returns the sound indexed at "target" 
		If target > count Or target < 0 Then 
			RuntimeError "Asked for a sound (by index) from a SoundPile that doesnt exist!" 
		End If 
		Return sounds[target] 
	End Method 
	Method getIndex:Int(target:String) 'Returns the index for a sound specified by "target" 
		For t = 0 To count-1 
			If target = names[t] Then 
				 Return t 
			End If 
		Next 
		Return -1
		RuntimeError "Asked for a sound's index (by name) from a SoundPile, and it doesnt exist!" 
 	End Method 
	Method add(targetname:String, targetpath:String) 'Adds a new sound and a new name into the arrays 
		count = count + 1
		names = names[..count]
		names[count-1] = targetname
		sounds = sounds[..count]
		sounds[count-1] = LoadSound(targetpath)
		If sounds[count-1] = Null Then
			RuntimeError "Couldnt load sound! might not exist!"
		End If
	End Method

	Method PrintContents() 'Prints the names of the sounds in the soundPile 
		For t = 0 To count-1 
			Print names[t] 
		Next 
	End Method 
 End Type 

 Function LoadSoundsFromDir(directory:String, thepile:SoundPile)
	'Loads all the jpegs and gifs and pngs in the specified "directory" into the soundPile "thepile"
	'Do not put a "/" at the end of the directory specification
	directory = directory + "/"
	Local fileNames:String[]
	fileNames=LoadDir(directory) 
	For t:String=EachIn fileNames 
		If Mid(t, t.length - 3, 4) = ".ogg" Then
			thepile.add(StripAll(t), directory + t) 
		End If
	Next 
 End Function
